@@ -14,7 +14,7 @@ use File::Slurp ();
 use File::Spec ();
 use IO::File ();
 
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 
 sub new {
     my ($self, %params) = @_;
@@ -581,17 +581,17 @@ sub _write {
 sub _compose_header {
     my $self = shift;
     my ($comments_header, $code_header) = ('','');
-    my $note = '# Note: this file has been initially generated by '.__PACKAGE__." $VERSION";
+    my $note = '# Note: this file has been initially generated by ' . __PACKAGE__ . " $VERSION";
     my $pragmas = "use strict;\nuse warnings;\n";
     if (defined($self->{make_code}{begin})) {
         $self->_do_verbose("*** Removing ExtUtils::MakeMaker as dependency\n");
         $self->{make_code}{begin} =~ s/[ \t]*(?:use|require)\s+ExtUtils::MakeMaker\s*;//;
 	if ($self->{make_code}{begin} =~ /(?:prompt|Verbose)\s*\(/s) {
-	    my $regexp = qr/^(.*?)(prompt|Verbose)\s*?\(['"](.*)['"]\);$/;
-	    for my $var (['make_code','begin'],['make_code','end']) {
-	        while ($self->{$var->[0]}{$var->[1]} =~ /$regexp/m) {
-	            my $replace = $1 . 'Module::Build->' . $2 . '("' . $3 . '")';
-	            $self->{$var->[0]}{$var->[1]} =~ s/$regexp/$replace/m;
+	    my $regexp = qr/^(.*?=\s*)(prompt|Verbose)\s*?\(['"](.*)['"]\);$/;
+	    for my $var (qw(begin end)) {
+	        while ($self->{make_code}{$var} =~ /$regexp/m) {
+	            my $replace = $1 . 'Module::Build->' . $2 . '("' . $3 . '");';
+	            $self->{make_code}{$var} =~ s/$regexp/$replace/m;
 	        }
 	    }
 	} 
